@@ -64,19 +64,19 @@ impl BinderCMLossComputer {
 impl CMLossComputer for BinderCMLossComputer {
     fn compute_loss(&self, state: &WorkingClustering, cms: &Array3<CountType>) -> f64 {
         let n_draws = cms.len_of(Axis(2));
-        let sum2 = state
+        let sum1 = state
             .occupied_clusters()
             .iter()
             .map(|i| BinderCMLossComputer::n_squared(state.size_of(*i)))
             .sum::<f64>()
             * n_draws as f64;
-        let mut sum1 = 0.0;
+        let mut sum2 = 0.0;
         let mut sum3 = 0.0;
         for draw_index in 0..n_draws {
             for other_index in 0..cms.len_of(Axis(1)) {
                 let n = cms[(0, other_index, draw_index)];
                 if n > 0 {
-                    sum1 += BinderCMLossComputer::n_squared(cms[(0, other_index, draw_index)]);
+                    sum2 += BinderCMLossComputer::n_squared(cms[(0, other_index, draw_index)]);
                     for main_label in state.occupied_clusters().iter() {
                         sum3 += BinderCMLossComputer::n_squared(
                             cms[(*main_label as usize + 1, other_index, draw_index)],
@@ -104,14 +104,14 @@ impl CMLossComputer for BinderCMLossComputer {
             0
         };
         let n_draws = cms.len_of(Axis(2));
-        let sum2 = (n_draws as f64) * ((state.size_of(to_label) - offset) as f64);
+        let sum1 = (n_draws as f64) * ((state.size_of(to_label) - offset) as f64);
         let to_index = to_label as usize + 1;
         let mut sum3 = 0.0;
         for draw_index in 0..n_draws {
             let other_index = draws.label(draw_index, item_index) as usize;
             sum3 += (cms[(to_index, other_index, draw_index)] - offset) as f64;
         }
-        sum2 - (self.a + 1.0) * sum3
+        self.a * sum1 - (self.a + 1.0) * sum3
     }
 }
 
@@ -303,7 +303,7 @@ impl<'a> VICMLossComputer<'a> {
 
 impl<'a> CMLossComputer for VICMLossComputer<'a> {
     fn compute_loss(&self, state: &WorkingClustering, cms: &Array3<CountType>) -> f64 {
-        let sum2: f64 = state
+        let sum1: f64 = state
             .occupied_clusters()
             .iter()
             .map(|i| self.cache.nlog2n(state.size_of(*i)))
@@ -312,12 +312,12 @@ impl<'a> CMLossComputer for VICMLossComputer<'a> {
         let n_draws = cms.len_of(Axis(2));
         let mut sum = 0.0;
         for draw_index in 0..n_draws {
-            let mut sum1 = 0.0;
+            let mut sum2 = 0.0;
             let mut sum3 = 0.0;
             for other_index in 0..cms.len_of(Axis(1)) {
                 let n = cms[(0, other_index, draw_index)];
                 if n > 0 {
-                    sum1 += self.cache.nlog2n(cms[(0, other_index, draw_index)]);
+                    sum2 += self.cache.nlog2n(cms[(0, other_index, draw_index)]);
                     for main_label in state.occupied_clusters().iter() {
                         sum3 += self
                             .cache
@@ -325,9 +325,9 @@ impl<'a> CMLossComputer for VICMLossComputer<'a> {
                     }
                 }
             }
-            sum += (self.a * sum1 + sum2 - a_plus_1 * sum3) / (state.n_items() as f64);
+            sum += sum2 - a_plus_1 * sum3;
         }
-        sum / (n_draws as f64)
+        ((self.a * sum1) + (sum / (n_draws as f64))) / (state.n_items() as f64)
     }
 
     fn change_in_loss(
@@ -345,7 +345,7 @@ impl<'a> CMLossComputer for VICMLossComputer<'a> {
             0
         };
         let n_draws = cms.len_of(Axis(2));
-        let sum2 = (n_draws as f64)
+        let sum1 = (n_draws as f64)
             * self
                 .cache
                 .nlog2n_difference(state.size_of(to_label) - offset);
@@ -357,7 +357,7 @@ impl<'a> CMLossComputer for VICMLossComputer<'a> {
                 .cache
                 .nlog2n_difference(cms[(to_index, other_index, draw_index)] - offset);
         }
-        sum2 - (self.a + 1.0) * sum3
+        self.a * sum1 - (self.a + 1.0) * sum3
     }
 }
 
@@ -1743,8 +1743,8 @@ pub fn minimize_by_enumeration(
 
 #[cfg(test)]
 mod tests_optimize {
-    use rand::thread_rng;
     use super::*;
+    use rand::thread_rng;
 
     #[test]
     fn test_max_scan() {
